@@ -136,7 +136,7 @@ def get_shopify_default_location():
     Getting default location id from config to process inventory
     '''
     shopify_config = __get_shopify_configs()
-    shopify_default_location = shopify_config['deafult_location']
+    shopify_default_location = shopify_config['shopify_deafult_location']
     return shopify_default_location
 
 def __get_paginated_url(response):
